# Property

The Property commands are used to create and manage reinforcements and to assign properties to a part.
(See also Material commands and Section commands.) The Property commands are methods of a Part object.

## Create properties for Part

```{eval-rst}
.. autoclass:: abaqus.Property.PropertyPart.PropertyPart
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Classes

### CompositeLayup

```{eval-rst}
.. autoclass:: abaqus.Property.CompositeLayup.CompositeLayup
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CompositePly

```{eval-rst}
.. autoclass:: abaqus.Property.CompositePly.CompositePly
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CompositePlyArray

```{eval-rst}
.. autoclass:: abaqus.Property.CompositePlyArray.CompositePlyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MaterialOrientation

```{eval-rst}
.. autoclass:: abaqus.Property.MaterialOrientation.MaterialOrientation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MaterialOrientationArray

```{eval-rst}
.. autoclass:: abaqus.Property.MaterialOrientationArray.MaterialOrientationArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PlyStackPlot

```{eval-rst}
.. autoclass:: abaqus.Property.PlyStackPlot.PlyStackPlot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PropertyAssembly

```{eval-rst}
.. autoclass:: abaqus.Property.PropertyAssembly.PropertyAssembly
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectionAssignment

```{eval-rst}
.. autoclass:: abaqus.Property.SectionAssignment.SectionAssignment
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectionAssignmentArray

```{eval-rst}
.. autoclass:: abaqus.Property.SectionAssignmentArray.SectionAssignmentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
